@@ -19,21 +19,19 @@ OpenADR Client for Python
 """
 
 import asyncio
-from functools import partial
-from dataclasses import asdict
+import inspect
+import logging
+import ssl
 from datetime import datetime, timedelta, timezone
+from functools import partial
 from http import HTTPStatus
 from random import randint
-import logging
-import inspect
-import ssl
 
 import aiohttp
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from openleadr import enums, objects
 from openleadr.messaging import create_message, parse_message
-from openleadr.utils import peek, generate_id, certificate_fingerprint, find_by, cron_config
-import xmltodict
+from openleadr.utils import generate_id, certificate_fingerprint, find_by, cron_config
 
 logger = logging.getLogger('openleadr')
 
@@ -241,10 +239,11 @@ class OpenADRClient:
             raise ValueError("The data_collection_mode should be 'incremental' or 'full'.")
 
         if data_collection_mode == 'full':
-            args = inspect.signature(myfunc).parameters
-            if not ('date_from' in args and 'date_to' in args):
-                raise TypeError("Your callback function must accept the 'date_from' and 'date_to' "
-                                "arguments if used with data_collection_mode 'full'.")
+            args = inspect.signature(callback).parameters
+            if not ('date_from' in args and 'date_to' in args and 'sampling_interval' in args):
+                raise TypeError("Your callback function must accept the 'date_from', 'date_to' "
+                                "and 'sampling_interval' arguments if used "
+                                "with data_collection_mode 'full'.")
 
         # Determine the correct item name, item description and unit
         if isinstance(measurement, objects.Measurement):
@@ -282,10 +281,10 @@ class OpenADRClient:
             report_specifier_id = report_specifier_id or generate_id()
             report = objects.Report(created_date_time=datetime.now(),
                                     report_name=report_name,
-                                    report_specifier_id=report_specifier_id)
+                                    report_specifier_id=report_specifier_id,
+                                    data_collection_mode=data_collection_mode)
             self.reports.append(report)
 
-
         # Add the new report description to the report
         target = objects.Target(resource_id=resource_id)
         r_id = generate_id()
@@ -361,7 +360,7 @@ class OpenADRClient:
         if ven_id:
             payload['ven_id'] = ven_id
         message = self._create_message('oadrCreatePartyRegistration',
-                                       request_id=generate_id(),
+                                       request_id=request_id,
                                        **payload)
         response_type, response_payload = await self._perform_request(service, message)
         if response_type is None:
@@ -430,7 +429,7 @@ class OpenADRClient:
         oadrCreateReport message that tells us which reports are to be sent.
         """
         request_id = generate_id()
-        payload = {'request_id': generate_id(),
+        payload = {'request_id': request_id,
                    'ven_id': self.ven_id,
                    'reports': reports}
 
@@ -441,12 +440,12 @@ class OpenADRClient:
         # Handle the subscriptions that the VTN is interested in.
         if 'report_requests' in response_payload:
             for report_request in response_payload['report_requests']:
-                result = await self.create_report(report_request)
+                await self.create_report(report_request)
 
         message_type = 'oadrCreatedReport'
         message_payload = {}
 
-        return response_type, response_payload
+        return message_type, message_payload
 
     async def create_report(self, report_request):
         """
@@ -460,10 +459,6 @@ class OpenADRClient:
         report_specifier_id = report_request['report_specifier']['report_specifier_id']
         report_back_duration = report_request['report_specifier'].get('report_back_duration')
         granularity = report_request['report_specifier']['granularity']
-        if 'report_interval' in report_request['report_specifier']:
-            report_interval = report_request['report_specifier']['report_interval']
-        else:
-            report_interval = None
 
         # Check if this report actually exists
         report = find_by(self.reports, 'report_specifier_id', report_specifier_id)
@@ -476,10 +471,6 @@ class OpenADRClient:
         requested_r_ids = []
         for specifier_payload in report_request['report_specifier']['specifier_payloads']:
             r_id = specifier_payload['r_id']
-            reading_type = specifier_payload['reading_type']
-
-            # Look up this report in our own reports index to make sure it is valid
-
             # Check if the requested r_id actually exists
             rd = find_by(report.report_descriptions, 'r_id', r_id)
             if not rd:
@@ -516,27 +507,21 @@ class OpenADRClient:
                 # If no granularity is specified, set it to the lowest sampling rate.
                 granularity = rd.sampling_rate.max_period
 
-            # Parse the report interval to set limits on the data collection
-            if 'report_interval' in report_request['report_specifier']:
-                report_interval = report_request['report_specifier']['report_interval']
-                report_start = report_interval['dtstart']
-                report_duration = report_interval['duration']
-            else:
-                report_start = datetime.now(timezone.utc)
-                duration = None
-
             requested_r_ids.append(r_id)
 
         callback = partial(self.update_report, report_request_id=report_request_id)
+
+        reporting_interval = report_back_duration or granularity
         job = self.scheduler.add_job(func=callback,
                                      trigger='cron',
-                                     **cron_config(granularity))
+                                     **cron_config(reporting_interval))
 
         self.report_requests.append({'report_request_id': report_request_id,
                                      'report_specifier_id': report_specifier_id,
                                      'report_back_duration': report_back_duration,
                                      'r_ids': requested_r_ids,
-                                     'granularity': granularity})
+                                     'granularity': granularity,
+                                     'job': job})
 
     async def update_report(self, report_request_id):
         """
@@ -547,41 +532,56 @@ class OpenADRClient:
         granularity = report_request['granularity']
         report_back_duration = report_request['report_back_duration']
         report_specifier_id = report_request['report_specifier_id']
+        report = find_by(self.reports, 'report_specifier_id', report_specifier_id)
+        data_collection_mode = report.data_collection_mode
 
         if report_request_id in self.incomplete_reports:
             logger.debug("We were already compiling this report")
             outgoing_report = self.incomplete_reports[report_request_id]
         else:
             logger.debug("There is no report in progress")
-            report = find_by(self.reports, 'report_specifier_id', report_request['report_specifier_id'])
             outgoing_report = objects.Report(report_request_id=report_request_id,
                                              report_specifier_id=report.report_specifier_id,
                                              report_name=report.report_name,
                                              intervals=[])
 
-            data_collection_mode = report.data_collection_mode
-            if data_collection_mode == 'full':
-                date_from = datetime.now(timezone.utc) - report_back_duration
-                callback = report_callbacks[(report.report_specifier_id, r_id)]
-
-
         intervals = outgoing_report.intervals or []
-        for r_id in report_request['r_ids']:
-            report_callback = self.report_callbacks[(report_specifier_id, r_id)]
-            result = report_callback()
-            if asyncio.iscoroutine(result):
-                result = await result
-            if isinstance(result, (int, float)):
-                result = [(datetime.now(timezone.utc), result)]
-            for dt, value in result:
-                logger.info(f"Adding {dt}, {value} to report")
-                report_payload = objects.ReportPayload(r_id=r_id, value=value)
-                intervals.append(objects.ReportInterval(dtstart=dt,
-                                                        report_payload=report_payload))
+        if data_collection_mode == 'full':
+            if report_back_duration is None:
+                report_back_duration = granularity
+            date_to = datetime.now(timezone.utc)
+            date_from = date_to - max(report_back_duration, granularity)
+            for r_id in report_request['r_ids']:
+                report_callback = self.report_callbacks[(report_specifier_id, r_id)]
+                result = report_callback(date_from=date_from,
+                                         date_to=date_to,
+                                         sampling_interval=granularity)
+                if asyncio.iscoroutine(result):
+                    result = await result
+                for dt, value in result:
+                    report_payload = objects.ReportPayload(r_id=r_id, value=value)
+                    intervals.append(objects.ReportInterval(dtstart=dt,
+                                                            report_payload=report_payload))
+
+        else:
+            for r_id in report_request['r_ids']:
+                report_callback = self.report_callbacks[(report_specifier_id, r_id)]
+                result = report_callback()
+                if asyncio.iscoroutine(result):
+                    result = await result
+                if isinstance(result, (int, float)):
+                    result = [(datetime.now(timezone.utc), result)]
+                for dt, value in result:
+                    logger.info(f"Adding {dt}, {value} to report")
+                    report_payload = objects.ReportPayload(r_id=r_id, value=value)
+                    intervals.append(objects.ReportInterval(dtstart=dt,
+                                                            report_payload=report_payload))
         outgoing_report.intervals = intervals
         logger.info(f"The number of intervals in the report is now {len(outgoing_report.intervals)}")
+
         # Figure out if the report is complete after this sampling
-        if report_back_duration is not None and report_back_duration > granularity:
+        if data_collection_mode == 'incremental' and report_back_duration is not None\
+                and report_back_duration > granularity:
             report_interval = report_back_duration.total_seconds()
             sampling_interval = granularity.total_seconds()
             expected_len = len(report_request['r_ids']) * int(report_interval / sampling_interval)
@@ -592,7 +592,7 @@ class OpenADRClient:
                 logger.debug("The report is not yet complete, will hold until it is.")
                 self.incomplete_reports[report_request_id] = outgoing_report
         else:
-            logger.info("Report is sent at the sampling rate, queueing now")
+            logger.info("Report will be sent now.")
             await self.pending_reports.put(outgoing_report)
 
     async def cancel_report(self, payload):
@@ -607,6 +607,7 @@ class OpenADRClient:
 
         while True:
             report = await self.pending_reports.get()
+            logger.info("Sending report!!!")
 
             service = 'EiReport'
             message = self._create_message('oadrUpdateReport', reports=[report])
@@ -614,10 +615,10 @@ class OpenADRClient:
             try:
                 response_type, response_payload = await self._perform_request(service, message)
             except Exception as err:
-                breakpoint()
-
-            if 'cancel_report' in response_payload:
-                await self.cancel_report(response_payload['cancel_report'])
+                logger.error(f"Unable to send the report to the VTN. Error: {err}")
+            else:
+                if 'cancel_report' in response_payload:
+                    await self.cancel_report(response_payload['cancel_report'])
 
     ###########################################################################
     #                                                                         #
@@ -648,8 +649,8 @@ class OpenADRClient:
             async with self.client_session.post(url, data=message) as req:
                 content = await req.read()
                 if req.status != HTTPStatus.OK:
-                    logger.warning(f"Non-OK status when performing a request "
-                                   f"to {url} with data {message}: {req.status} {content.decode('utf-8')}")
+                    logger.warning(f"Non-OK status when performing a request to {url} with data "
+                                   f"{message}: {req.status} {content.decode('utf-8')}")
                     return None, {}
                 logger.debug(content.decode('utf-8'))
         except aiohttp.client_exceptions.ClientConnectorError as err:
@@ -663,12 +664,12 @@ class OpenADRClient:
         try:
             message_type, message_payload = parse_message(content)
         except Exception as err:
-            logger.error(f"The incoming message could not be parsed or validated.")
+            logger.error(f"The incoming message could not be parsed or validated: {err}")
             return None, {}
         return message_type, message_payload
 
     async def _on_event(self, message):
-        logger.debug(f"The VEN received an event")
+        logger.debug("The VEN received an event")
         try:
             result = self.on_event(message)
             if asyncio.iscoroutine(result):
