@@ -147,6 +147,7 @@ class Event:
             self.active_period = ActivePeriod(dtstart=dtstart,
                                               duration=duration)
 
+
 @dataclass
 class Response:
     response_code: int
@@ -224,7 +225,7 @@ class Report:
     dtstart: datetime = None                # For delivering values
     duration: timedelta = None              # For delivering values
     intervals: List[ReportInterval] = None  # For delivering values
-    data_collection_mode = 'incremental'
+    data_collection_mode: str = 'incremental'
 
     def __post_init__(self):
         if self.created_date_time is None:
